@@ -100,11 +100,13 @@ type Form x = Html -> MForm (HandlerT App IO) (FormResult x, Widget)
 instance Yesod App where
     approot = ApprootMaster $ appRoot . settings
 
-    -- Store session data on the client in encrypted cookies,
-    -- default session idle timeout is 120 minutes
-    makeSessionBackend _ = fmap Just $ defaultClientSessionBackend
-                             (120 * 60)
-                             ".hledger-web_client_session_key.aes"
+--    -- Store session data on the client in encrypted cookies,
+--    -- default session idle timeout is 120 minutes
+--    makeSessionBackend _ = fmap Just $ defaultClientSessionBackend
+--                             (120 * 60)
+--                             ".hledger-web_client_session_key.aes"
+    -- don't use session data
+    makeSessionBackend _ = return Nothing
 
     defaultLayout widget = do
         master <- getYesod
@@ -125,6 +127,7 @@ instance Yesod App where
 
         pc <- widgetToPageContent $ do
             addStylesheet $ StaticR css_bootstrap_min_css
+            addStylesheet $ StaticR css_bootstrap_datepicker_standalone_min_css
              -- load these things early, in HEAD:
             toWidgetHead [hamlet|
                           <script type="text/javascript" src="@{StaticR js_jquery_min_js}">
@@ -132,6 +135,7 @@ instance Yesod App where
                          |]
             addScript $ StaticR js_bootstrap_min_js
             -- addScript $ StaticR js_typeahead_bundle_min_js
+            addScript $ StaticR js_bootstrap_datepicker_min_js
             addScript $ StaticR js_jquery_url_js
             addScript $ StaticR js_jquery_cookie_js
             addScript $ StaticR js_jquery_hotkeys_js
@@ -146,11 +150,12 @@ instance Yesod App where
         staticRootUrl <- (staticRoot . settings) <$> getYesod
         withUrlRenderer $(hamletFile "templates/default-layout-wrapper.hamlet")
 
+    -- TODO outdated, still needed ?
     -- This is done to provide an optimization for serving static files from
     -- a separate domain. Please see the staticRoot setting in Settings.hs
-    urlRenderOverride y (StaticR s) =
-        Just $ uncurry (joinPath y (Settings.staticRoot $ settings y)) $ renderRoute s
-    urlRenderOverride _ _ = Nothing
+    -- urlRenderOverride y (StaticR s) =
+    --     Just $ uncurry (joinPath y (Settings.staticRoot $ settings y)) $ renderRoute s
+    urlParamRenderOverride _ _ _ = Nothing
 
 #ifndef DEVELOPMENT
     -- This function creates static content files in the static folder
@@ -163,11 +168,6 @@ instance Yesod App where
     -- Place Javascript at bottom of the body tag so the rest of the page loads first
     jsLoader _ = BottomOfBody
 
-    -- What messages should be logged. The following includes all messages when
-    -- in development, and warnings and errors in production.
-    shouldLog _ _source level =
-        development || level == LevelWarn || level == LevelError
-
 -- This instance is required to use forms. You can modify renderMessage to
 -- achieve customized and internationalized form validation messages.
 instance RenderMessage App FormMessage where
@@ -297,19 +297,11 @@ getLastMessage = cached getMessage
 addform :: Text -> ViewData -> HtmlUrl AppRoute
 addform _ vd@VD{..} = [hamlet|
 
-<script language="javascript">
+<script>
   jQuery(document).ready(function() {
 
     /* set up typeahead fields */
 
-    datesSuggester = new Bloodhound({
-      local:#{listToJsonValueObjArrayStr dates},
-      limit:100,
-      datumTokenizer: function(d) { return [d.value]; },
-      queryTokenizer: function(q) { return [q]; }
-    });
-    datesSuggester.initialize();
-
     descriptionsSuggester = new Bloodhound({
       local:#{listToJsonValueObjArrayStr descriptions},
       limit:100,
@@ -331,7 +323,6 @@ addform _ vd@VD{..} = [hamlet|
     });
     accountsSuggester.initialize();
 
-    enableTypeahead(jQuery('input#date'), datesSuggester);
     enableTypeahead(jQuery('input#description'), descriptionsSuggester);
     enableTypeahead(jQuery('input#account1, input#account2, input#account3, input#account4'), accountsSuggester);
 
@@ -340,10 +331,13 @@ addform _ vd@VD{..} = [hamlet|
 <form#addform method=POST .form>
  <div .form-group>
   <div .row>
-   <div .col-md-2 .col-xs-6 .col-sm-6>
-    <input #date .typeahead .form-control .input-lg type=text size=15 name=date placeholder="Date" value="#{defdate}">
-   <div .col-md-10 .col-xs-6 .col-sm-6>
-    <input #description .typeahead .form-control .input-lg type=text size=40 name=description placeholder="Description">
+   <div .col-md-3 .col-xs-6 .col-sm-6>
+    <div #dateWrap .input-group .date>
+     <input #date required lang=en name=date .form-control .input-lg placeholder="Date" >
+     <div .input-group-addon>
+      <span .glyphicon .glyphicon-th>
+   <div .col-md-9 .col-xs-6 .col-sm-6>
+    <input #description required .typeahead .form-control .input-lg type=text size=40 name=description placeholder="Description">
  <div .account-postings>
   $forall n <- postingnums
     ^{postingfields vd n}
@@ -361,10 +355,8 @@ addform _ vd@VD{..} = [hamlet|
     (or ctrl +, ctrl -)
 |]
  where
-  defdate = "" :: String -- #322 don't set a default, typeahead(?) clears it on tab. See also hledger.js
-  dates = ["today","yesterday","tomorrow"] :: [String]
   descriptions = sort $ nub $ map tdescription $ jtxns j
-  accts = sort $ journalAccountNamesUsed j
+  accts = journalAccountNamesDeclaredOrImplied j
   escapeJSSpecialChars = regexReplaceCI "</script>" "<\\/script>" -- #236
   listToJsonValueObjArrayStr as  = preEscapedString $ escapeJSSpecialChars $ encode $ JSArray $ map (\a -> JSObject $ toJSObject [("value", showJSON a)]) as
   numpostings = 4
