@@ -22,7 +22,7 @@ import Network.Wai.Handler.Launch (runHostPortUrl)
 #if !MIN_VERSION_base(4,8,0)
 import Control.Applicative ((<$>))
 #endif
-import Control.Monad (when)
+import Control.Monad
 import Data.Text (pack)
 import System.Exit (exitSuccess)
 import System.IO (hFlush, stdout)
@@ -43,10 +43,7 @@ hledgerWebMain = do
 
 runWith :: WebOpts -> IO ()
 runWith opts
-  | "h"               `inRawOpts` (rawopts_ $ cliopts_ opts) = putStr (showModeUsage webmode) >> exitSuccess
-  | "help"            `inRawOpts` (rawopts_ $ cliopts_ opts) = printHelpForTopic (topicForMode webmode) >> exitSuccess
-  | "man"             `inRawOpts` (rawopts_ $ cliopts_ opts) = runManForTopic (topicForMode webmode) >> exitSuccess
-  | "info"            `inRawOpts` (rawopts_ $ cliopts_ opts) = runInfoForTopic (topicForMode webmode) >> exitSuccess
+  | "help"            `inRawOpts` (rawopts_ $ cliopts_ opts) = putStr (showModeUsage webmode) >> exitSuccess
   | "version"         `inRawOpts` (rawopts_ $ cliopts_ opts) = putStrLn prognameandversion >> exitSuccess
   | "binary-filename" `inRawOpts` (rawopts_ $ cliopts_ opts) = putStrLn (binaryfilename progname)
   | otherwise = do
@@ -54,16 +51,22 @@ runWith opts
     withJournalDo' opts web
 
 withJournalDo' :: WebOpts -> (WebOpts -> Journal -> IO ()) -> IO ()
-withJournalDo' opts cmd = do
-  f <- head `fmap` journalFilePathFromOpts (cliopts_ opts) -- XXX head should be safe for now
+withJournalDo' opts@WebOpts {cliopts_ = cliopts} cmd = do
+  f <- head `fmap` journalFilePathFromOpts cliopts -- XXX head should be safe for now
 
   -- https://github.com/simonmichael/hledger/issues/202
   -- -f- gives [Error#yesod-core] <stdin>: hGetContents: illegal operation (handle is closed) for some reason
   -- Also we may be writing to this file. Just disallow it.
   when (f == "-") $ error' "hledger-web doesn't support -f -, please specify a file path"
 
-  readJournalFile Nothing Nothing True f >>=
-   either error' (cmd opts . journalApplyAliases (aliasesFromOpts $ cliopts_ opts))
+  let fn = cmd opts
+         . pivotByOpts cliopts
+         . anonymiseByOpts cliopts
+         . journalApplyAliases (aliasesFromOpts cliopts)
+       <=< journalApplyValue (reportopts_ cliopts)
+       <=< journalAddForecast cliopts
+         . generateAutomaticPostings (reportopts_ cliopts)
+  readJournalFile Nothing Nothing True f >>= either error' fn
 
 -- | The web command.
 web :: WebOpts -> Journal -> IO ()
