@@ -17,17 +17,4 @@ import           Settings             as Import
 import           Settings.Development as Import
 import           Settings.StaticFiles as Import
 
-#if __GLASGOW_HASKELL__ >= 704
-import           Data.Monoid          as Import (
-#if !MIN_VERSION_base(4,8,0)
-                                                 Monoid (mappend, mempty, mconcat),
-#endif
-                                                 (<>))
-#else
-import           Data.Monoid          as Import
-                                                 (Monoid (mappend, mempty, mconcat))
-
-infixr 5 <>
-(<>) :: Monoid m => m -> m -> m
-(<>) = mappend
-#endif
+import           Data.Monoid          as Import ((<>))
